@@ -43,6 +43,15 @@ proc Mh_Init {} {
 	    if [info exists d2] { set exmh(mh_vers) [string trim $d2] }
 	}
     }
+    # Test for now, only present in nmh 1.6+dev and 1.7
+   if { $nmh} {
+        catch {MhExec mhical -version} d
+        regexp {.*-- *([^ ]*)[ ]} $d d2
+        if [info exists d2] {set exmh(have_mhical) 1 }
+        catch {MhExec gcalcli --version} d
+        regexp {.*v([.0-9]*)[ ]} $d d2
+        if [info exists d2] {set exmh(have_gcalcli) 1 }
+   }
 }
 
 proc Mh_Preferences {} {
@@ -1155,16 +1164,16 @@ proc MhSetMailDrops {} {
 	catch {puts stderr "Multidrop needs $name mapping file"}
     }
 }
-proc Mhn_DeleteOrig { msgid } {
+proc Mhbuild_DeleteOrig { msgid } {
     global mhProfile
     set path $mhProfile(path)/$mhProfile(draft-folder)/$mhProfile(delprefix)$msgid
     if {[file exists $path.orig]} {
-	Exmh_Debug Mhn_DeleteOrig deleting $path.orig
+	Exmh_Debug Mhbuild_DeleteOrig deleting $path.orig
 	File_Delete $path.orig
     }
 }
 
-proc Mhn_RenameOrig { msgid } {
+proc Mhbuild_RenameOrig { msgid } {
     global mhProfile
     set path $mhProfile(path)/$mhProfile(draft-folder)/$mhProfile(delprefix)$msgid
     if {[file exists $path.orig]} {
