@@ -1081,14 +1081,11 @@ proc Mime_WithTextFile {fileIOVar tkw part body} {
 }
 
 proc Mime_SetFileEncoding {fileIO part} {
-    global tcl_version
-    if {$tcl_version >= 8.1} {
-	set charset [Mime_GetCharset {} $part]
-	regsub {^us-} $charset {} charset
-	regsub {^(mac|iso)-} $charset {\1} charset
-	if {[catch {fconfigure $fileIO -encoding $charset} err]} {
-	    Exmh_Debug "Mime_SetFileEncoding: $err"
-	}
+    set charset [Mime_GetCharset {} $part]
+    regsub {^us-} $charset {} charset
+    regsub {^(mac|iso)-} $charset {\1} charset
+    if {[catch {fconfigure $fileIO -encoding $charset} err]} {
+        Exmh_Debug "Mime_SetFileEncoding: $err"
     }
 }
 
@@ -1308,7 +1305,12 @@ proc MimeShowTime { tkw time } {
     global mime
 
     catch {
-	set msgtime   [clock scan $time]
+	set msgtime   [regsub -all {\([^)]*\)} $time {}]
+	set msgtime   [string trim $msgtime]
+	if [regexp {.* -0000$} $msgtime] {
+	    return
+	}
+	set msgtime   [clock scan $msgtime -format "%a, %d %b %Y %T %Z"]
 	set localtime [clock format $msgtime -format " %T"]
 	if { [string first $localtime $time] == -1 } {
 	    Preferences_Resource mime(localTimeFormat) localTimeFormat \
