@@ -73,7 +73,7 @@ proc Msg_HighlightInit { t } {
     foreach tagname {attrib_me quote_me attrib1 attrib2 attrib3 attrib4 \
 			 attrib5 quote1 quote2 quote3 quote4 quote5 signature \
 			 listsig msheader1 msheader2 udiffold udiffnew \
-			 bugrpttok} {
+			 bugrpttok spamass embolded} {
         set rval [option get . b_$tagname {}]
         eval {$t tag configure $tagname} $rval
     }
@@ -92,6 +92,7 @@ proc MsgShow { msgid } {
     # Display the current message in a text widget
     global msg exwin exmh mhProfile mimeHdr mime
 
+    Exwin_SeeToplevelMsg
     if {$msg(dpy) == $msgid} {
 	return
     }
@@ -253,20 +254,25 @@ proc Hook_MsgShowListHeaders {msgPath headervar} {
     foreach index [array names header 0=1,hdr,list-*] {
 	# Get the suffix portion of the header name
 	regsub {^.*,list-} $index {} name
-	# Remove comments
-	regsub -all {\([^()]*\)} $header($index) {} h
-	# Remove whitespace
-	regsub -all " " $h {} h
-	# Loop through the fields
-	foreach f [split $h ,] {
-	    # Stricture #1
-	    if {[string index $f 0] == "<"} {
-		# Stricture #2
-		regexp "<(.*)>" $f match url
-		lappend menuitems $name $url
-	    } else {
+	# Stricture #1
+	# Remove leading white space and comments
+        regsub {^[ \n\t]*(\([^)]*\)[ \n\t]*)*} $header($index) {} h
+        if {[string index $h 0] == "<"} {
+	    # Loop through the fields
+	    while {[regexp -indices {<([^>]*)>} $h match i]} {
+                set url [eval {string range $h} $i]
 		# Stricture #3
-		break
+		if [regexp {^([^:]*):} $url -> proto] {
+		    lappend menuitems $name $proto $url
+		}
+		set next [expr [lindex $match 1]+1]
+		set h [string range $h $next end]
+		# Stricture #2
+                regsub {^[ \n\t]*(\([^)]*\)[ \n\t]*)*} $h {} h
+		if {[string index $h 0] != ","} {
+		    break
+		}
+                regsub {^[ \n\t]*(\([^)]*\)[ \n\t]*)*} $h {} h
 	    }
 	}
     }
@@ -276,9 +282,9 @@ proc Hook_MsgShowListHeaders {msgPath headervar} {
 	} else {
 	    set menu [Widget_AddMenuB $exwin(mopButtons) list "List..." {right padx 1 filly}]
 	}
-	$exwin(mopButtons).list.m delete 1 99
-	foreach {name url} $menuitems {
-	    Widget_AddMenuItem $menu $name [list URI_StartViewer $url]
+	$exwin(mopButtons).list.m delete 0 99
+	foreach {name proto url} $menuitems {
+	    Widget_AddMenuItem $menu "$name ($proto)" [list URI_StartViewer $url]
 	}
     } else {
 	catch {destroy $exwin(mopButtons).list}
@@ -416,6 +422,7 @@ proc Hook_MsgHighlight_jcl-beautify {t {start 1.0} {end end}} {
     set in_msheader 0
     set in_listsig 0
     set in_udiff 0
+    set in_spamass 0
 
     set endx [$t index end]
     for {set idx [expr int($start)]} {$idx <= $endx} {incr idx} {
@@ -426,6 +433,7 @@ proc Hook_MsgHighlight_jcl-beautify {t {start 1.0} {end end}} {
 	    set in_msheader 0
 	    set in_signature 0
 	    set in_udiff 0
+	    set in_spamass 0
 	} 
 
 	if {[regexp {^---------+$} $txt] || [regexp {^______+$} $txt]} {
@@ -433,15 +441,17 @@ proc Hook_MsgHighlight_jcl-beautify {t {start 1.0} {end end}} {
 	    set in_msheader 0
 	    set in_signature 0
 	    set in_udiff 0
+	    set in_spamass 0
 	} 
 
 	if {[regexp {^--* *Original Message *--*$} $txt] 
-	    || [regexp {^[-]+ *Forwarded Message *$} $txt]
+	    || [regexp {^[-]+ (Begin )?Forwarded Message *-*$} $txt]
 	    || [regexp {^[-]+ *End of Forwarded Message *$} $txt]} {
 	    set in_listsig 0
 	    set in_msheader 1
 	    set in_signature 0
 	    set in_udiff 0
+	    set in_spamass 0
 	}
 
 	if {[regexp {^-- ?$} $txt]} {
@@ -449,6 +459,7 @@ proc Hook_MsgHighlight_jcl-beautify {t {start 1.0} {end end}} {
 	    set in_msheader 0
 	    set in_signature 1
 	    set in_udiff 0
+	    set in_spamass 0
 	} 
 
 	if {[regexp {^@@.*@@$} $txt]} {
@@ -456,8 +467,17 @@ proc Hook_MsgHighlight_jcl-beautify {t {start 1.0} {end end}} {
 	    set in_msheader 0
 	    set in_signature 0
 	    set in_udiff 1
+	    set in_spamass 0
 	} 
 
+	if {[regexp {^ pts rule name              description$} $txt]} {
+	    set in_listsig 0
+	    set in_msheader 0
+	    set in_signature 0
+	    set in_udiff 0
+	    set in_spamass 1
+	}
+
 	if {$in_udiff == 1} {
 	    if {[regexp {^-} $txt d line]} {
 		$t tag add udiffold $idx.0 $idx.end
@@ -479,6 +499,15 @@ proc Hook_MsgHighlight_jcl-beautify {t {start 1.0} {end end}} {
 	    continue
 	} 
 
+	if {[regexp {\*.+\*} $txt bolded]} {
+	    if {[regexp {^[^*]*\*} $txt beforefirststar]} {
+		set firstlen [expr [string length $beforefirststar]]
+		set endpos [expr $firstlen + [string length $bolded] - 2]
+		$t tag add embolded $idx.[expr $firstlen] $idx.[expr $endpos]
+		$t tag raise embolded
+	    }
+	}
+
 # Enable this block if you can recognise quotes of your (written by
 # you) text.  This will then attempt to coloruise that text using
 # the attrib_me and quote_me colour pair.
@@ -489,12 +518,12 @@ proc Hook_MsgHighlight_jcl-beautify {t {start 1.0} {end end}} {
 #	if {[regexp {^(\+>)} $txt d quote] 
 #	    || [regexp {^(John>)} $txt d quote] 
 #	    || [regexp {^(JBeck>)} $txt d quote]} {
-#	    $t tag add attrib_me $idx.0 $idx.[expr [string length $quote] - 1]
-#	    $t tag add quote_me  $idx.[expr [string length $quote] - 1] $idx.end
+#	    $t tag add attrib_me $idx.0 $idx.[string length $quote]
+#	    $t tag add quote_me  $idx.[string length $quote] $idx.end
 #	    continue
-#        }
+#	}
 
-	lassign {qt_cnt qt_str} [MsgHighlightQuoteLevel $txt]
+	lassign [MsgHighlightQuoteLevel $txt] qt_cnt qt_str
 	if {$qt_cnt >= 5} {
 	    set qt_cnt 5
 	}
@@ -514,6 +543,11 @@ proc Hook_MsgHighlight_jcl-beautify {t {start 1.0} {end end}} {
 	    continue
 	}
 
+	if {$in_spamass == 1} {
+	    $t tag add spamass $idx.0 $idx.end
+	    continue
+	}
+
 #	$t tag add body $idx.0 $idx.end
     }
 }
@@ -550,29 +584,38 @@ proc MsgShow_BeautifyBugrpt {t {start 1.0} {end end}} {
 	if {[regexp {^Subject: BugId [0-9].* Has been Updated .*$} $txt] ||\
 	    [regexp {^Subject: BugId [0-9].* Priority value ch.*$} $txt] ||\
 	    [regexp {^Subject: BugId [0-9].* New .* Created, .*$}  $txt] ||\
-	    [regexp {^Subject: BugId [0-9].* Responsible .*er$}    $txt]} {
+	    [regexp {^Subject: BugId [0-9].* Responsible .*er$}    $txt] ||\
+	    [regexp {^Subject: CR [0-9].* responsible .*er}        $txt] ||\
+	    [regexp {^Subject: CR [0-9].* Updated .*$}             $txt] ||\
+	    [regexp {^Subject: CR [0-9].* Created .*$}             $txt] ||\
+	    [regexp {^Subject: CR [0-9].* Redispatched .*$}        $txt] ||\
+	    [regexp {^Subject: CR [0-9].* Has been .*$}            $txt]} {
 	    set in_bugrpt 1
 	}
 	if {$in_bugrpt == 1} {
-	    if {[regexp {^ Synopsis:} $txt d line]} {
+	    if {[regexp {^ ?\*?Synopsis\*?:} $txt d line]} {
+		$t tag add bugrpttok $idx.0 $idx.end
+	    } elseif {[regexp {^  ?\*?Description\*?:} $txt d line]} {
 		$t tag add bugrpttok $idx.1 $idx.end
-	    } elseif {[regexp {^ Description:} $txt d line]} {
+	    } elseif {[regexp {^  ?\*?Justification\*?:} $txt d line]} {
 		$t tag add bugrpttok $idx.1 $idx.end
-	    } elseif {[regexp {^ Justification:} $txt d line]} {
+	    } elseif {[regexp {^  ?\*?Work ?around\*?:} $txt d line]} {
 		$t tag add bugrpttok $idx.1 $idx.end
-	    } elseif {[regexp {^ Work around:} $txt d line]} {
+	    } elseif {[regexp {^  ?\*?Suggested [Ff]ix\*?:} $txt d line]} {
 		$t tag add bugrpttok $idx.1 $idx.end
-	    } elseif {[regexp {^ Suggested fix:} $txt d line]} {
-		$t tag add bugrpttok $idx.1 $idx.end
-	    } elseif {[regexp {^	Evaluation:} $txt d line]} {
+	    } elseif {[regexp {^(	|  )\*?Evaluation\*?:} $txt d line]} {
 		$t tag add bugrpttok $idx.1 $idx.end
 	    } elseif {[regexp {^ Interest list:} $txt d line]} {
 		$t tag add bugrpttok $idx.1 $idx.15
-	    } elseif {[regexp {^ Comments:} $txt d line]} {
+	    } elseif {[regexp {^  \*?Interest List\*?:} $txt d line]} {
+		$t tag add bugrpttok $idx.2 $idx.16
+	    } elseif {[regexp {^  ?\*?Comments\*?:} $txt d line]} {
 		$t tag add bugrpttok $idx.1 $idx.end
 	    } elseif {[regexp {^ See also:} $txt d line]} {
 		$t tag add bugrpttok $idx.1 $idx.10
-	    } elseif {[regexp {^ Public Summary:} $txt d line]} {
+	    } elseif {[regexp {^  \*?See Also\*?:} $txt d line]} {
+		$t tag add bugrpttok $idx.2 $idx.11
+	    } elseif {[regexp {^ \*?Public Summary\*?:} $txt d line]} {
 		$t tag add bugrpttok $idx.1 $idx.end
 	    }
 	}
