@@ -1,6 +1,12 @@
 # pgpGpg.tcl
 
-# $Log: pgpGpg.tcl,v $
+# $Log$
+# Revision 1.18  2017/04/22 01:14:14  sysphrog
+# Fix gnupg Comment field to dynamically update to the currently running version
+#
+# Revision 1.17  2017/03/25 03:02:30  az143
+# Summary: small patch in pgpGPG to support long and short keyids
+#
 # Revision 1.16  2012/01/22 22:54:45  az143
 # az@debian.org repaired gpg cipher option handling
 #
@@ -146,7 +152,7 @@ proc Pgp_gpg_Preferences {} {
 handling to GnuPG's gpg-agent. This option overrides and disables 
 the pgpKeepPass option." ] \
                 [list pgp(gpg,comment) gpgComment \
-"Exmh [set exmh(version)]" "GnuPG Comment" \
+"Exmh [eval set exmh(version)]" "GnuPG Comment" \
 "Specify the comment GnuPG should put in the comment field
 of encrypted or signed text."] \
                 [list pgp(gpg,modulepath) gpgModulePath \
@@ -385,12 +391,12 @@ set pgp(gpg,pat_dropKeys) {(^|\n)(pub|sub|sec|ssb|uid):[dren]:[^\n]+}
 set pgp(gpg,pat_splitKeys) \n
 # Patterns that match out interesting keys
 set pgp(gpg,pat_keySec) \
-                {^(pub|sec):[^:]*:[^:]*:([^:]*):[0-9A-F][0-9A-F][0-9A-F][0-9A-F][0-9A-F][0-9A-F][0-9A-F][0-9A-F]([^:]+):[^:]*:[^:]*:[^:]*:[^:]*:([^:]+).*$}
+		{^(pub|sec):[^:]*:[^:]*:([^:]*):([0-9A-F]+):[^:]*:[^:]*:[^:]*:[^:]*:([^:]+).*$}
 set pgp(gpg,pat_keySec_sub) \
-                {^(ssb):[^:]*:[^:]*:([^:]+):[0-9A-F][0-9A-F][0-9A-F][0-9A-F][0-9A-F][0-9A-F][0-9A-F][0-9A-F]([^:]+):[^:]*:[^:]*:[^:]*:[^:]*:[^:]*.*$}
+                {^(ssb):[^:]*:[^:]*:([^:]+):([0-9A-F]+):[^:]*:[^:]*:[^:]*:[^:]*:[^:]*.*$}
 set pgp(gpg,pat_keyPub) $pgp(gpg,pat_keySec)
 set pgp(gpg,pat_keyPub_sub) \
-                {^(sub):[^:]*:[^:]*:([^:]+):[0-9A-F][0-9A-F][0-9A-F][0-9A-F][0-9A-F][0-9A-F][0-9A-F][0-9A-F]([^:]+):[^:]*:[^:]*:[^:]*:[^:]*:[^:]*.*$}
+                {^(sub):[^:]*:[^:]*:([^:]+):([0-9A-F]+):[^:]*:[^:]*:[^:]*:[^:]*:[^:]*.*$}
 set pgp(gpg,pat_uid) \
                 {^(uid):[^:]*:[^:]*:[^:]*:[^:]*:[^:]*:[^:]*:[^:]*:[^:]*:([^:]+).*$}
 # TclCmd to match out userid and keyid
@@ -442,7 +448,7 @@ set pgp(gpg,pat_checkError) "(BAD_PASSPHRASE\[^\n]+)\n"
 #######################
 # Exec_DetDecryptKeyid
 set pgp(gpg,args_getDecryptKeyid) {--dry-run $in}
-set pgp(gpg,pat_getDecryptKeyid) "NEED_PASSPHRASE ........(........)"
+set pgp(gpg,pat_getDecryptKeyid) "NEED_PASSPHRASE \[\[:alnum:]_]+ (\[\[:alnum:]_]+)"
 set pgp(gpg,pat_getDecryptSym) "NEED_PASSPHRASE_SYM"
 
 ###############
