@@ -7,7 +7,12 @@
 
 # todo:
 
-# $Log: pgpMisc.tcl,v $
+# $Log$
+# Revision 1.24  1999/11/08 16:37:57  kchrist
+# Had to roll back and re-do a previous bug fix. I used exmh(ctype) when
+# I should have used exmh($id,action). They both seem to contain the same
+# information but exmh($id,action) gets set in more cases than exmh(ctype).
+#
 # Revision 1.23  1999/09/27 23:18:46  kchrist
 # More PGP changes. Consolidated passphrase entry to sedit field or
 # pgpExec routine. Made the pgp-sedit field aware of pgp(keeppass)
@@ -354,47 +359,54 @@ proc Pgp_Misc_GetHeader { in } {
 
 #
 proc Misc_PostProcess { srcfile } {
-    global mhProfile pgp
+    global mhProfile pgp exmh
 
     set id [SeditId $srcfile]
 
-    set dstfile [Mh_Path $mhProfile(draft-folder) new]
-    set curfile $srcfile
-
-    # read the header to see what postprocessing has to be done
-    set in [open $curfile r]
-    set mailheader [Pgp_Misc_GetHeader $in]
-    close $in
-
-    # call the pgp postprocesing if necessary
-    # (checking for $pgp(version,$id) is necessary because
-    # drafts generated by exmh for PGP key retrieval will not
-    # have their own PGP variables set)
-    if {$pgp(enabled) && [info exists pgp(version,$id)] && \
-	    ($pgp(encrypt,$id) || $pgp(sign,$id) != "none")} {
-	set v $pgp(version,$id)
-
-	# Take care of the "cur" passphrase. This may come from a Sedit or
-	# WhatNow window OR from a call to either Pgp_SetMyName or 
-	# Pgp_SetSeditPgpVersion.
-	if {[info exists pgp(cur,pass,$id)]} {
-	    if {[string length $pgp(cur,pass,$id)] > 0} {
-		set keyid [lindex $pgp($v,myname,$id) 0]
-		set pgp($v,pass,$keyid) $pgp(cur,pass,$id)
-		if {![info exists pgp(timeout,$keyid)]} {
-		    Pgp_SetPassTimeout $v $keyid
-		}
-	    }
-	    Pgp_SetPassTimeout cur $id	    
-	}
-
-# Danger Wil Robinson!
-	#Exmh_Debug pass=>$pgp($v,pass,$keyid)<
-	Pgp_Process $v $curfile $dstfile
-	set curfile $dstfile
+    # There are several reasons for not doing this PGP PostProcessing.
+    # !$pgp(enabled) - PGP is disabled
+    # ![info exists pgp(version,$id)] - Most likely draft is an automatic 
+    #        draft lacking the necessary PGP variables. Such drafts are
+    #        generated when querying an email key server, for example.
+    # (!$pgp(encrypt,$id) || $pgp(sign,$id)=="none") - Nothing to do.
+    # ($exmh($id,action) == "dist") - Redistributed messages should be left 
+    #        alone.
+    if { !$pgp(enabled) || \
+	    ![info exists pgp(version,$id)] || \
+	    (!$pgp(encrypt,$id) && $pgp(sign,$id)=="none") || \
+	    ($exmh($id,action) == "dist") } {
+	return [file tail $srcfile]
     }
 
-    return [file tail $curfile]
+    # Thing are fine, do the PostProcessing
+    set dstfile [Mh_Path $mhProfile(draft-folder) new]
+    set v $pgp(version,$id)
+
+    # read the header to see what postprocessing has to be done
+    #set in [open $curfile r]
+    #set mailheader [Pgp_Misc_GetHeader $in]
+    #close $in
+
+
+    # Take care of the "cur" passphrase. This may come from a Sedit or
+    # WhatNow window OR from a call to either Pgp_SetMyName or 
+    # Pgp_SetSeditPgpVersion.
+    if {[info exists pgp(cur,pass,$id)]} {
+	if {[string length $pgp(cur,pass,$id)] > 0} {
+	    set keyid [lindex $pgp($v,myname,$id) 0]
+	    set pgp($v,pass,$keyid) $pgp(cur,pass,$id)
+	    if {![info exists pgp(timeout,$keyid)]} {
+		Pgp_SetPassTimeout $v $keyid
+	    }
+	}
+	Pgp_SetPassTimeout cur $id	    
+    }
+
+# Danger Wil Robinson!
+    #Exmh_Debug pass=>$pgp($v,pass,$keyid)<
+    Pgp_Process $v $srcfile $dstfile
+
+    return [file tail $dstfile]
 }
 
 #
