@@ -39,7 +39,7 @@ proc PickSetup {} {
     catch {unset pick}
     set pick(panes) 0
     set pick(addtosel) 0
-    set pick(fields) {subject from to cc tocc before after search component}
+    set pick(fields) {subject fromtocc from to cc tocc before after search sender mailing-list component}
 
     set f [Widget_Frame .pick rim0 Rim]
     Widget_BeginEntries 20 25 Pick_It
@@ -89,7 +89,7 @@ proc PickAddField {f pane what} {
 	    break
 	}
     }
-    Widget_BeginEntries 10 25 Pick_It $last
+    Widget_BeginEntries 13 25 Pick_It $last
 
     set l [string toupper [string index $what 0]][string range $what 1 end]
     if [string match component $what] {
@@ -128,7 +128,7 @@ proc PickAddOrField {pane who} {
 }
 proc Pick_It {} {
     global pick exmh
-    set cmd [list exec pick +$exmh(folder) -list]
+    set cmd [list exec pick +$exmh(folder)]
     set inpane 0
     set hadpane 0
     for {set pane 1} {$pane <= $pick(panes)} {incr pane} {
@@ -161,9 +161,12 @@ proc Pick_It {} {
 			lappend cmd -lbrace
 		}
 		switch -exact $field \
-		component {lappend cmd --$pick($pane,$who,component) $text} \
-		tocc      {lappend cmd -lbrace -to $text -or -cc $text -rbrace} \
-		default   {lappend cmd -$field $text}
+		component    {lappend cmd --$pick($pane,$who,component) $text} \
+		tocc         {lappend cmd -lbrace -to $text -or -cc $text -rbrace} \
+		fromtocc     {lappend cmd -lbrace -from $text -or -to $text -or -cc $text -rbrace} \
+		sender       {lappend cmd -lbrace --sender $text -rbrace} \
+		mailing-list {lappend cmd -lbrace --mailing-list $text -rbrace} \
+		default      {lappend cmd -$field $text}
 	        set or 1
 	    }
 	    if $or {
@@ -173,20 +176,23 @@ proc Pick_It {} {
 	}
 	if {$inpane == $pane} {lappend cmd -rbrace}
     }
-    set msgs $pick(msgs)
-    foreach s $pick(sequence) {
-	lappend msgs -sequence $s
+    foreach seq $pick(sequence) {
+	lappend cmd -sequence $seq
     }
+    lappend cmd -list
 
-    Exmh_Debug Pick_It $cmd $msgs
-    busy PickInner $cmd $msgs
+    Exmh_Debug Pick_It $cmd $pick(msgs)
+    busy PickInner $cmd $pick(msgs)
+    foreach seq $pick(sequence) {
+	Ftoc_ShowSequence $seq $pick(msgs)
+    }
     Exmh_Focus
 }
 proc PickInner {cmd msgs} {
     global pick
-    Exmh_Status "$cmd $msgs" red
+    Exmh_Status "$cmd $msgs" warning
     if [catch [concat $cmd $msgs] ids] {
-	Exmh_Status "Fail: [string range $ids 2 end]" purple
+	Exmh_Status "Fail: [string range $ids 2 end]" error
 	return
     }
     set pick(ids) [split $ids \n]
@@ -195,23 +201,38 @@ proc PickInner {cmd msgs} {
 	Ftoc_RangeUnHighlight
     }
     Ftoc_PickMsgs $pick(ids) $pick(addtosel)
-    Exmh_Status "Pick hit [llength $pick(ids)] msgs" blue
+    Exmh_Status "Pick hit [llength $pick(ids)] msgs"
 }
 proc PickMarkSeen {} {
-    global exmh pick
+    global exmh pick mhProfile
     if ![info exists pick(ids)] {
 	return
     }
-    Mh_MarkSeen $exmh(folder) $pick(ids)
-    Ftoc_MarkSeen $pick(ids)
-    foreach id $pick(ids) {
-	Flist_MsgSeen $id
-    }
+    Seq_Del $exmh(folder) $mhProfile(unseen-sequence) $pick(ids)
+    Ftoc_ShowSequence $mhProfile(unseen-sequence) $pick(ids)
 }
 proc Pick_MarkSeen {} {
-    global exmh pick
-    Exmh_Status "Clearing unseen sequence..." red
-    set pick(ids) [Mh_Unseen $exmh(folder)]
+    global exmh pick mhProfile
+    Exmh_Status "Clearing unseen sequence..." warning
+    set pick(ids) [Seq_Msgs $exmh(folder) $mhProfile(unseen-sequence)]
     busy PickMarkSeen
-    Exmh_Status ok blue
+    Exmh_Status ok
+}
+
+# Ted Cabeen's Catchup-to-current
+# http://www.xray.mpe.mpg.de/mailing-lists/exmh/2002-09/msg00100.html
+proc Pick_Mark2CurSeen {} {
+    global exmh mhProfile msg
+    set results {}
+    Exmh_Status "Clearing unseen up to cur..." warning
+    Mh_SetCur $exmh(folder) $msg(id)
+    set unseen [Mh_Sequence $exmh(folder) $mhProfile(unseen-sequence) ]
+    foreach elem $unseen {
+         if { $elem <= $msg(id) } {
+            lappend results $elem
+         }
+    }
+    busy Seq_Del $exmh(folder) $mhProfile(unseen-sequence) $results
+    Ftoc_ShowSequence $mhProfile(unseen-sequence) $results
+    Exmh_Status ok
 }
