@@ -28,7 +28,7 @@ proc ScanFolder {folder adjustDisplay} {
     } else {
 	set samefolder 0
 	set cacheFile $mhProfile(path)/$folder/.xmhcache
-	if [catch {open $cacheFile} input] {
+	if {! [Scan_CacheValid $folder] || [catch {open $cacheFile} input]} {
 	    # No cache, scan last N messages
 	    Exmh_Status "Limit scan $folder last:$ftoc(scanSize) - Rescan?" warn
 	    set input  [open "|$mhProfile(scan-proc) [list +$folder] \
@@ -240,10 +240,16 @@ proc Scan_CacheValid {folder} {
     global mhProfile exmh
     set cacheFile $mhProfile(path)/$folder/.xmhcache
     if {![file exists $cacheFile] || ![file size $cacheFile]} {
+	Exmh_Debug No/empty scan cache for +$folder
 	return 0
     }
+    # note that nmh's folder command produces lockfiles 
+    # in the respective directory, which means the directory modification date 
+    # will be changed and cause a false "cache invalid" decision
+    # if folder is run before Scan_CacheUpdate on folder entry
     if {[file mtime $mhProfile(path)/$folder] >
 	[file mtime $cacheFile]} {
+	Exmh_Debug Outdated scan cache for +$folder
 	return 0
     }
     return 1
@@ -268,14 +274,14 @@ proc Scan_CacheUpdate {} {
 	set curLine [Ftoc_ClearCurrent]			;# Clear +
         if [file writable $cacheFile] {
             set scancmd "exec $mhProfile(scan-proc) [list +$folder] \
-		    -width $ftoc(scanWidth) -noheader > [list $cacheFile]"
+		    -width $ftoc(scanWidth) -noheader >@ [open $cacheFile w 0$mhProfile(msg-protect)]"
             if [catch $scancmd err] {
                 Exmh_Status "failed to rescan folder $folder: $err" warn
             }
         }
 	Ftoc_Change $curLine	;# Restore it
     } elseif [catch {
-	set cacheIO [open $cacheFile w]
+	set cacheIO [open $cacheFile w 0$mhProfile(msg-protect)]
 	set curLine [Ftoc_ClearCurrent]			;# Clear +
 	set display [$exwin(ftext) get 1.0 "end -1 char"]
 	Ftoc_Change $curLine	;# Restore it
@@ -303,7 +309,7 @@ proc Scan_Move { folder scanlinesR new } {
     }
     set len [string length $prefix]
     set fmt [format "%%%dd%%s" $len]
-    set cacheIO [open $cacheFile a]
+    set cacheIO [open $cacheFile a 0$mhProfile(msg-protect)]
     for {set i [expr [llength $scanlinesR]-1]} {$i >= 0} {incr i -1} {
 	set line [lindex $scanlinesR $i]
 	if [regsub {( *[0-9]+)(\+)} $line {\1 } newline] {
@@ -332,14 +338,14 @@ proc Scan_AllFolders { {force 0} } {
 	if {$force || ! [Scan_CacheValid $f]} {
 	    puts $out "catch \{send $myname \{Exmh_Status \"scan +$f\"\}\}"
 	    puts $out "catch {
-		set out \[open $mhProfile(path)/$f/.xmhcache w $mhProfile(msg-protect)\]
+		set out \[open $mhProfile(path)/$f/.xmhcache w 0$mhProfile(msg-protect)\]
 		exec $mhProfile(scan-proc) +$f -width $ftoc(scanWidth) -noheader >@\$out
 		close \$out
 	    }"
 	}
     }
     puts $out "catch \{send $myname \{Exmh_Status \"scans completed\"\}\}"
-    puts $out "exec rm $ctx.\[pid\]"
+    puts $out "file delete -force $ctx.\[pid\]"
     puts $out exit
     close $out
     Exmh_Status "wish -f [Env_Tmp]/scancmds &"
