@@ -112,7 +112,7 @@ proc SeditSelFmtArg {t} {
 	Widget_AddBut .par.but format "Format" {
 	    Exmh_Status "Formatting Selection"
 	    if [catch {exec par -$par(options) -B=$par(body) -Q=$par(quote) -P=$par(protect) $par(width) << $par(txt)} res] {
-	        Exmh_Status "Error: Invalid options for Par" red
+	        Exmh_Status "Error: Invalid options for Par" warning
 	    } else {
             	if ![catch {$par(t) index sel.first} tndx] {
                     $par(t) delete sel.first sel.last
@@ -130,7 +130,7 @@ proc SeditSelFmtArg {t} {
 
 
 proc SeditSelSpell { f t } {
-    global sedit editor wish
+    global sedit editor wish argv0
 
     set parent [file root $f]
     catch {[destroy $parent.spell]}
@@ -145,12 +145,16 @@ proc SeditSelSpell { f t } {
     puts $out $txt
     close $out
 
+    set async_hack 0
     switch -- $sedit(spell) {
-	ispell {set prog {exmh-async xterm -e ispell}}
+	ispell {set prog "exmh-async xterm -e ispell" ; set async_hack 1}
 	custom {set prog $editor(spell)}
 	default {set prog spell}
     }
-    if [string match exmh-async* $prog] {
+    if {[regexp ^exmh-async $prog]} {
+	set async_hack 1
+    }
+    if {$async_hack} {
 	# exmh-async isn't really right
 	# craft a wish script instead
 	set script [Env_Tmp]/exmh.w[pid].[file tail $t]
@@ -160,11 +164,11 @@ proc SeditSelSpell { f t } {
 	}
 	puts $out "wm withdraw ."
 	puts $out "catch \{"
-	puts $out "exec [lrange $editor(spell) 1 end] $path"
+	puts $out "exec [lrange $prog 1 end] $path"
 	puts $out "\}"
 	puts $out [list send [winfo name .] [list SeditReplaceSel $t $path]]
-	puts $out "exec rm -f $path"
-	puts $out "exec rm -f $script"
+	puts $out "file delete -force $path"
+	puts $out "file delete -force $script"
 	puts $out exit
 	close $out
 	exec $wish -f $script &
@@ -173,7 +177,7 @@ proc SeditSelSpell { f t } {
 
     # Display the results of the spell program
     catch {eval exec $prog {$path}} result
-    catch {exec rm $path}
+    catch {file delete -force $path}
 
     set f2 [Widget_Frame $parent spell {top fill}]
 
