@@ -30,33 +30,33 @@
 #
 
 proc text_menu_post {w wx wy x y} {
-	global tk_priv
+	global tkPriv
 	set tags [$w tag names @$wx,$wy]
 	Exmh_Debug $tags
-	set tk_priv(textmenu) {}
+	set tkPriv(textmenu) {}
 	foreach tag $tags {
 	    catch {
 		if {[winfo class $w.$tag] == "Menu"} {
-		    set tk_priv(textmenu) $w.$tag
+		    set tkPriv(textmenu) $w.$tag
 		}
 	    }
 	}
-	catch {menu_post $tk_priv(textmenu) $w $x $y}
+	catch {menu_post $tkPriv(textmenu) $w $x $y}
 }
 proc text_menu_unpost {w} {
-	global tk_priv
-	catch {menu_unpost $tk_priv(textmenu) $w}
-	catch {unset tk_priv(textmenu)}
+	global tkPriv
+	catch {menu_unpost $tkPriv(textmenu) $w}
+	catch {unset tkPriv(textmenu)}
 }
 
 # post the given menu at the given position in the widget (or canvas) w
 
 proc menu_post {menu w x y} {
-	global tk_priv
+	global tkPriv
 
 	$menu activate none
-	$menu post $x $y
-	set tk_priv(cursor) [lindex [$w config -cursor] 4]
+	tk_popup $menu $x $y
+	set tkPriv(cursor) [$w cget -cursor]
 	$w config -cursor arrow
 	grab set $w
 }
@@ -65,10 +65,10 @@ proc menu_post {menu w x y} {
 # unpost the given menu in the widget
 
 proc menu_unpost {menu w} {
-	global tk_priv
+	global tkPriv
 
-	$menu unpost
-	catch {$w config -cursor $tk_priv(cursor)}
+	tkMenuUnpost $menu
+	catch {$w config -cursor $tkPriv(cursor)}
 	grab release $w
 }
 
@@ -87,10 +87,7 @@ proc menu_invoke {menu w} {
 # setup the bindings for a local widget menu
 
 proc menu_bind {menu w} {
-    global tk_version
-    if {$tk_version >= 4.0} {
-	bindtags $menu $menu
-    }
+    bindtags $menu $menu
     bind $menu <Any-ButtonPress> {}
     bind $menu <Any-ButtonRelease> "menu_invoke $menu $w"
     bind $menu <2> { }
